<!-- 专业装备 -->
<template>
  <el-dialog
    :before-close="handleClose"
    :close-on-click-modal="false"
    :visible="visible"
    custom-class="bbsl-location-dialog"
    title="课目教案"
    top="5vh"
    width="75%"
    append-to-body
  >
    <el-container>
      <el-aside class="left-aside" width="270px">
        <el-card class="box-card org-find-card" shadow="never">
          <div slot="header" class="clearfix">
            <span>按专业装备查找</span>
          </div>
          <div class="common-tree-container">
            <div class="container-head">
              <el-input
                v-model="filterText"
                clearable
                placeholder="输入关键字进行过滤"
              >
              </el-input>
              <img
                v-if="expandAll"
                src="@/assets/img/quanjusuoxiao2.png"
                @click="expandHandle"
              />
              <img
                v-else
                src="@/assets/img/quanping.png"
                @click="expandHandle"
              />
              <i class="el-icon-refresh" @click="getTree"></i>
            </div>
            <el-tree
              v-if="treeData.length"
              ref="tree"
              :current-node-key="currentKey"
              :data="treeData"
              :expand-on-click-node="expandAll"
              :filter-node-method="filterNode"
              :props="defaultProps"
              highlight-current
              node-key="id"
              @node-click="handleNodeClick"
            >
            </el-tree>
          </div>
        </el-card>
      </el-aside>
      <el-container>
        <el-header class="middle-header">
          <div style="padding: 10px 0">
            <el-input
              v-model="queryParam.querys[0].value"
              clearable
              placeholder="请输入名称"
              prefix-icon="el-icon-search"
              size="small"
              style="width:380px"
              @keyup.enter.native="searchEnterFun"
            >
            </el-input>
            <el-button
              icon="el-icon-search"
              size="small"
              style="margin-left: 20px"
              type="primary"
              @click="searchEnterFun()"
              >查询
            </el-button>
            <el-button icon="el-icon-refresh" size="small" @click="reset()"
              >重置
            </el-button>
          </div>
        </el-header>
        <el-main style="padding:0">
          <el-table
            ref="multipleTable"
            :data="UserData"
            :row-key="binRowKey"
            border
            height="400"
            size="medium"
            stripe
            @select="manualSelection"
          >
            <el-table-column
              align="center"
              type="selection"
              width="45"
            ></el-table-column>
            <el-table-column label="课目信息" prop="name"></el-table-column>
            <el-table-column
              label="训练类别"
              prop="trainTypeName"
            ></el-table-column>
          </el-table>
        </el-main>
        <el-pagination
          ref="paginationPanel"
          :current-page="queryParam.pageBean.page"
          :page-size="queryParam.pageBean.pageSize"
          :page-sizes="[20, 30, 40, 50]"
          :total="total"
          align="right"
          background
          layout="prev, pager, next,total, sizes, jumper"
          @size-change="handleSizeChange"
          @current-change="handleCurrentChange"
        ></el-pagination>
      </el-container>
      <el-aside class="select-aside" width="200px">
        <el-header class="select-header">
          <span>已选择</span>
        </el-header>
        <div class="select-tree-div">
          <el-tree
            ref="selectTree"
            :data="selectUser"
            :props="selectUserProps"
            :render-content="renderContent"
            node-key="name"
          ></el-tree>
        </div>
      </el-aside>
    </el-container>
    <span slot="footer" class="dialog-footer" style="text-align: center;">
      <el-button size="small" type="primary" @click="dialogConfirm"
        >确认</el-button
      >
      <el-button size="small" @click="handleClose">取消</el-button>
    </span>
  </el-dialog>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import {refineRequestBody} from '@/utils/requestWrappers'
import * as api from '@/api/examDataMenu/examKnowledgeData/teachingResourceData' // import questionListMenu from '@/api/examination/questionListMenu.js'
import * as publicApi from '@/api/examDataMenu/examKnowledgeData'
export default {
  mixins: [TableMixin],
  name: 'SelectOrganize',
  props: ['userTypeId'],
  data() {
    return {
      // 查询对象
      queryParam: {
        pageBean: {pageSize: 20, page: 1, total: 0},
        querys: [
          {operation: 'EQUAL', property: 'knowledgeTypeId'},
          {operation: 'LIKE', property: 'name'},
          {operation: 'LIKE', property: 'pushOrg'}
        ],
        sorter: [
          {direction: 'DESC', property: 'pushTime'},
          {direction: '', property: 'auditTime'}
        ]
      },

      search: '',
      treeData: [],
      defaultProps: {
        children: 'children',
        label: 'name'
      },
      visible: false,
      UserData: [],
      selectUser: [],
      selectUserProps: {
        label: 'name'
      },
      nameArr: [],
      multipleSelection: null,
      params: {
        majorIds: [],
        subjectIds: []
      },
      userlength: null,
      userInfoVos: [],
      currentKey: null,
      filterText: '',
      expandAll: false
    }
  },
  created() {},
  watch: {
    filterText(val) {
      this.$refs.tree.filter(val)
    },
    currentKey: {
      handler(value) {
        if (value) {
          this.$nextTick(() => {
            this.$refs.tree.setCurrentKey(this.currentKey)
          })
        }
      },
      immediate: true,
      valType: false
    }
  },
  mounted() {},
  methods: {
    expandHandle() {
      console.log(this.$refs.tree.store)
      this.expandAll = !this.expandAll
      this.expandNodes(this.$refs.tree.store.root)
    },
    // 遍历树形数据，设置每一项的expanded属性，实现展开收起
    expandNodes(node) {
      node.expanded = this.expandAll
      for (let i = 0; i < node.childNodes.length; i++) {
        node.childNodes[i].expanded = this.expandAll
        if (node.childNodes[i].childNodes.length > 0) {
          this.expandNodes(node.childNodes[i])
        }
      }
    },
    filterNode(value, data) {
      if (!value) return true
      return data.name.indexOf(value) !== -1
    },
    add(val) {
      console.log(val)
      this.selectUser = []
      this.visible = true
      if (val) {
        this.userInfoVos = val
        this.selectUser = JSON.parse(JSON.stringify(val))
        this.userlength = val.length
      }
      console.log(111111111, this.selectUser)
      this.multipleSelection = null
      this.getTree()
    },
    searchName() {
      this.getTree()
    },
    // 获取表格数据
    async loadData() {
      try {
        this.loading = true
        const {total = 0, rows = []} = await api.tableData(
          refineRequestBody(this.queryParam)
        )
        this.total = total
        this.UserData = rows
        this.$nextTick(() => {
          this.selectUser.forEach(s => {
            console.log(1)

            this.UserData.forEach(u => {
              if (s.id == u.id) {
                this.$refs.multipleTable.toggleRowSelection(u)
              }
            })
          })
        })
      } finally {
        this.loading = false
      }
    },
    // 获取人员类别树
    getTree() {
      publicApi.getTree('1').then(res => {
        if (res.length > 0) {
          this.treeData = [
            {
              name: '教学资源目录',
              id: '',
              parentId: '',
              children: res
            }
          ]
          this.currentKey = this.treeData[0].id
          this.queryParam.querys[0].value = this.currentKey
          this.loadData()
        }
      })
    },
    // 显示
    handleShow(val) {
      this.visible = true
      this.selectUser = []
      this.multipleSelection = null
      this.getTree()
      this.loadData(1)
    },

    // 关闭新增人员窗口
    handleClose() {
      this.visible = false
      this.treeData = []
      this.UserData = []
      this.selectUser = []
    },
    // 树
    handleNodeClick(item) {
      this.queryParam.querys[0].value = item.id
      this.loadData()
    },
    // 中间列表
    searchEnterFun() {
      this.loadData(1)
    },
    // 重置
    reset() {
      this.queryParam.querys[0].value = ''

      this.loadData(1)
    },
    dialogConfirm() {
      this.$emit('getUser', this.selectUser)
      this.handleClose()
    },
    binRowKey(row) {
      return row.id
    },
    selectable(row) {
      let type = true
      this.userInfoVos.forEach((u, ui) => {
        if (ui <= this.userlength) {
          if (row.id == u.id) {
            type = false
          }
        }
      })
      return type
      // return true
    },
    manualSelection(selection, row) {
      console.log(row)
      //先判断当前操作flag
      //true勾选还是false取消
      let flag = selection.some(item => {
        if (row.id == item.id) return true
      })
      if (flag) {
        this.selectUser.push(row)
      } else {
        this.selectUser.forEach((s, si) => {
          if (s.id == row.id) {
            this.selectUser.splice(si, 1)
          }
        })
      }
    },
    handleSelectionChange(val) {
      this.selectUser = val
      // this.multipleSelection = row;
      // // 清除 所有勾选项
      // this.$refs.multipleSelection.clearSelection()
      // // 当表格数据都没有被勾选的时候 就返回
      // // 主要用于将当前勾选的表格状态清除
      // if (selection.length == 0) return
      // this.$refs.multipleSelection.toggleRowSelection(row, true);
    },
    renderContent(h, {node, data, store}) {
      return (
        <span
          class="custom-tree-node"
          on-mouseover={() => {
            this.show = true
          }}
          on-mouseout={() => {
            this.show = false
          }}
        >
          <span>{data.name}</span>
          <span>
            <el-button
              style="width:100%;border:0;margin:0;"
              size="mini"
              // icon="el-icon-delete"
              type="text"
              on-click={() => this.remove(data)}
            >
              删除
            </el-button>
          </span>
        </span>
      )
    },
    remove(val) {
      console.log(val)
      this.selectUser.forEach((u, ui) => {
        if (u.id == val.id) {
          this.selectUser.splice(ui, 1)
        }
      })
      this.userInfoVos = JSON.parse(JSON.stringify(this.selectUser))
      this.userlength = this.selectUser.length
      this.loadData(1)
    }
  }
}
</script>

<style lang="scss" scoped>
::v-deep .el-dialog__body {
  height: 100% !important;
  max-height: 80%;
}

.left-aside {
  border-right: 1px solid #eee;
  padding: 10px;
}

.select-aside {
  border-left: 1px solid #eee;
}

.el-card {
  height: 96% !important;
}

.el-tree {
  max-height: 400px;
  overflow-y: auto;
  border: none;
}

.select-header {
  border-bottom: 1px solid #ebeef5;
}

::v-deep .el-table__header-wrapper .el-checkbox {
  //找到表头那一行，然后把里面的复选框隐藏掉
  display: none;
}

.container-head {
  display: flex;
  align-items: center;

  img {
    width: 28px;
    height: 28px;
    margin: auto 5px;
    cursor: pointer;
  }

  i {
    font-size: 28px;
    font-weight: 600;
    cursor: pointer;
  }
}
</style>
